==> 0.0.15.tar.gz: lib/nui_miniprogram_message.dart <==
import 'dart:convert';
import 'dart:typed_data';

import 'package:nui_core/nui_core.dart';
import 'nui_miniprogram_enum.dart';

class NUIMiniProgramMessage {
  static const DEFAULT_CHANNEL = "NUIMiniProgramDefaultChannel";
  static const _MESSAGE_RECEIVED = "NUIMessageReceived";

  NUIMiniProgramMessage.empty();
  NUIMiniProgramMessage({String id, this.channel, this.data}){
    this.id = id ?? randomUUID();
  }

  String channel;
  String data;
  String id;

  NUIMiniProgramMessage response({String data, String channel}){
    return NUIMiniProgramMessage(
      id: this.id,
      channel: channel ?? this.channel,
      data: data
    );
  }

  bool isResponseReceived(){
    return match(data, _MESSAGE_RECEIVED);
  }

  NUIMiniProgramMessage responseReceived(){
    return response(data: _MESSAGE_RECEIVED);
  }

  NUIMiniProgramMessage fromJson(Map<String, dynamic> json){
    return NUIMiniProgramMessage(channel: json["channel"], data: json["data"], id: json["id"]);
  }

  Map<String, dynamic> toJson(){
    return {
      "channel": channel,
      "data": data,
      "id": id
    };
  }
}

class NUIMiniProgramFile{
  NUIMiniProgramFile({this.filename, this.bytesString, this.extensions, Uint8List bytes}){
    bytesString = utf8.decode(bytes);
  }

  String filename;
  String bytesString;
  List<String> extensions;
  
  Uint8List bytesFromString(){
    return utf8.encode(bytesString);
  }

  NUIMiniProgramFile fromJson(Map<String, dynamic> json){
    return NUIMiniProgramFile(
      filename: json["filename"],
      bytesString: json["bytes"],
      extensions: List<String>.from(json["extensions"] ?? [])
    );
  }

  Map<String, dynamic> toJson(){
    return {
      "filename": filename,
      "bytes": bytesString,
      "extensions": extensions
    };
  }
}

class NUIMiniProgramInternalMessage{
  NUIMiniProgramInternalMessage({this.type, this.data});
  NUIMiniProgramEventType type;
  String data;

  NUIMiniProgramInternalMessage fromJson(Map<String, dynamic> json){
    return NUIMiniProgramInternalMessage(type: eventTypefromValue(json["type"]), data: json["data"]);
  }

  Map<String, dynamic> toJson(){
    return {
      "type": type.value,
      "data": data
    };
  }
}

==> 0.0.16.tar.gz: lib/nui_miniprogram_message.dart <==
import 'dart:convert';
import 'dart:typed_data';

import 'package:nui_core/nui_core.dart';
import 'nui_miniprogram_enum.dart';

class NUIMiniProgramMessage {
  static const DEFAULT_CHANNEL = "NUIMiniProgramDefaultChannel";
  static const _MESSAGE_RECEIVED = "NUIMessageReceived";

  NUIMiniProgramMessage.empty();
  NUIMiniProgramMessage({String id, this.channel, this.data}){
    this.id = id ?? randomUUID();
  }

  String channel;
  String data;
  String id;

  NUIMiniProgramMessage response({String data, String channel}){
    return NUIMiniProgramMessage(
      id: this.id,
      channel: channel ?? this.channel,
      data: data
    );
  }

  bool isResponseReceived(){
    return match(data, _MESSAGE_RECEIVED);
  }

  NUIMiniProgramMessage responseReceived(){
    return response(data: _MESSAGE_RECEIVED);
  }

  NUIMiniProgramMessage fromJson(Map<String, dynamic> json){
    return NUIMiniProgramMessage(channel: json["channel"], data: json["data"], id: json["id"]);
  }

  Map<String, dynamic> toJson(){
    return {
      "channel": channel,
      "data": data,
      "id": id
    };
  }
}

class NUIMiniProgramFile{
  NUIMiniProgramFile({this.filename, this.bytesString, this.extensions, Uint8List bytes}){
    bytesString = String.fromCharCodes(bytes);
    // bytesString = utf8.decode(bytes);
  }

  String filename;
  String bytesString;
  List<String> extensions;
  
  Uint8List bytesFromString(){
    return Uint8List.fromList(bytesString.codeUnits);
    // return utf8.encode(bytesString);
  }

  NUIMiniProgramFile fromJson(Map<String, dynamic> json){
    return NUIMiniProgramFile(
      filename: json["filename"],
      bytesString: json["bytes"],
      extensions: List<String>.from(json["extensions"] ?? [])
    );
  }

  Map<String, dynamic> toJson(){
    return {
      "filename": filename,
      "bytes": bytesString,
      "extensions": extensions
    };
  }
}

class NUIMiniProgramInternalMessage{
  NUIMiniProgramInternalMessage({this.type, this.data});
  NUIMiniProgramEventType type;
  String data;

  NUIMiniProgramInternalMessage fromJson(Map<String, dynamic> json){
    return NUIMiniProgramInternalMessage(type: eventTypefromValue(json["type"]), data: json["data"]);
  }

  Map<String, dynamic> toJson(){
    return {
      "type": type.value,
      "data": data
    };
  }
}
